@@ -1,4 +1,4 @@
-#  Copyright (c) 2023 SIMBA Chain Inc. https://simbachain.com
+#  Copyright (c) 2024 SIMBA Chain Inc. https://simbachain.com
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -27,6 +27,7 @@ from typing import IO, Any, AnyStr, Dict, List, Optional, Tuple, Union
 
 from pydantic import BaseModel, field_validator, model_validator, FieldValidationInfo
 
+
 class AuthFlow(str, Enum):
     CLIENT_CREDENTIALS = "client_credentials"
 
@@ -99,9 +100,9 @@ class MethodCallArgs(BaseModel):
 
 class SearchFilter(BaseModel):
     filters: List[FieldFilter] = []
-    fields: Optional[List[str]]
-    limit: Optional[int]
-    offset: Optional[int]
+    fields: Optional[List[str]] = None
+    limit: Optional[int] = None
+    offset: Optional[int] = None
 
     def has_filter(self, field: str):
         for filter in self.filters:
@@ -109,6 +110,12 @@ class SearchFilter(BaseModel):
                 return True
         return False
 
+    def has_filter_value(self, field: str, op: FilterOp, value: Any):
+        for filter in self.filters:
+            if filter.field == field and filter.op == op and filter.value == value:
+                return True
+        return False
+
     def add_filter(self, field_filter: FieldFilter):
         self.filters.append(field_filter)
 
